==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/part/KPrPlaceholderPictureStrategy.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrPlaceholderPictureStrategy.h"

#include <QString>
#include <QFileDialog>
#include <QUrl>

#include <KoImageCollection.h>
#include <KoDocumentResourceManager.h>
#include <KoImageData.h>
#include <KoShape.h>
#include <KoNetAccess.h>

#include "StageDebug.h"


KPrPlaceholderPictureStrategy::KPrPlaceholderPictureStrategy()
: KPrPlaceholderStrategy( "graphic" )
{
}

KPrPlaceholderPictureStrategy::~KPrPlaceholderPictureStrategy()
{
}

KoShape *KPrPlaceholderPictureStrategy::createShape(KoDocumentResourceManager *rm)
{
    KoShape * shape = 0;

    QUrl url = QFileDialog::getOpenFileUrl();
    if ( !url.isEmpty() ) {
        shape = KPrPlaceholderStrategy::createShape(rm);

        KoImageCollection *collection = rm->imageCollection();
        Q_ASSERT(collection);

        QString tmpFile;
        if (KIO::NetAccess::download(url, tmpFile, 0)) {
            QImage image(tmpFile);
            if (!image.isNull()) {
                //setSuffix(url.prettyUrl());
                KoImageData *data = collection->createImageData(image);
                if (data->isValid()) {
                    shape->setUserData( data );
                    // TODO the pic should be fit into the space provided
                    shape->setSize( data->imageSize() );
                }
            }
            KIO::NetAccess::removeTempFile(tmpFile);
        } else {
            warnStage << "open image" << url << "failed";
        }
    }
    return shape;
}

==> calligra_24.12.3+dfsg.orig.tar.xz: calligra-24.12.3/stage/part/KPrPlaceholderPictureStrategy.cpp <==
/* This file is part of the KDE project
 * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "KPrPlaceholderPictureStrategy.h"

#include <QFileDialog>
#include <QString>
#include <QUrl>

#include <KoDocumentResourceManager.h>
#include <KoImageCollection.h>
#include <KoImageData.h>
#include <KoNetAccess.h>
#include <KoShape.h>

#include "StageDebug.h"

KPrPlaceholderPictureStrategy::KPrPlaceholderPictureStrategy()
    : KPrPlaceholderStrategy("graphic")
{
}

KPrPlaceholderPictureStrategy::~KPrPlaceholderPictureStrategy() = default;

KoShape *KPrPlaceholderPictureStrategy::createShape(KoDocumentResourceManager *rm)
{
    KoShape *shape = nullptr;

    QUrl url = QFileDialog::getOpenFileUrl();
    if (!url.isEmpty()) {
        shape = KPrPlaceholderStrategy::createShape(rm);

        KoImageCollection *collection = rm->imageCollection();
        Q_ASSERT(collection);

        QString tmpFile;
        if (KIO::NetAccess::download(url, tmpFile, nullptr)) {
            QImage image(tmpFile);
            if (!image.isNull()) {
                // setSuffix(url.prettyUrl());
                KoImageData *data = collection->createImageData(image);
                if (data->isValid()) {
                    shape->setUserData(data);
                    // TODO the pic should be fit into the space provided
                    shape->setSize(data->imageSize());
                }
            }
            KIO::NetAccess::removeTempFile(tmpFile);
        } else {
            warnStage << "open image" << url << "failed";
        }
    }
    return shape;
}
